==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/AnnotationLayerProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, typeCast, delegateCombine, delegateRemove, markType } from "igniteui-react-core";
import { IAnnotationLayerProxy_$type } from "./IAnnotationLayerProxy";
import { CrosshairLayer } from "./CrosshairLayer";
import { ValueLayer } from "./ValueLayer";
import { CalloutLayer } from "./CalloutLayer";
import { FinalValueLayer } from "./FinalValueLayer";
import { TrendLineLayer } from "./TrendLineLayer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { DoubleCollection } from "igniteui-react-core";
/**
 * @hidden
 */
var AnnotationLayerProxy = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AnnotationLayerProxy, _super);
    function AnnotationLayerProxy() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._container = null;
        return _this;
    }
    Object.defineProperty(AnnotationLayerProxy.prototype, "container", {
        get: function () {
            return this._container;
        },
        set: function (a) {
            this._container = a;
        },
        enumerable: false,
        configurable: true
    });
    AnnotationLayerProxy.prototype.matchesType = function (a) {
        if (!a.eu) {
            return false;
        }
        return true;
    };
    AnnotationLayerProxy.prototype.createCrosshairLayer = function () {
        var a = new CrosshairLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createValueLayer = function () {
        var a = new ValueLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createCalloutLayer = function () {
        var a = new CalloutLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createFinalValueLayer = function () {
        var a = new FinalValueLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createTrendLineLayer = function () {
        var a = new TrendLineLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.setCrosshairHorizontalLineVisibility = function (a, b) {
        a.ac1 = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairVerticalLineVisibility = function (a, b) {
        a.ac2 = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairHorizontalLineStroke = function (a, b) {
        a.acp = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairVerticalLineStroke = function (a, b) {
        a.acq = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairXAxisForeground = function (a, b) {
        a.act = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairYAxisForeground = function (a, b) {
        a.acw = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairXAxisBackground = function (a, b) {
        a.acr = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairYAxisBackground = function (a, b) {
        a.acu = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairYAxisPrecision = function (a, b) {
        a.aay = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairXAxisPrecision = function (a, b) {
        a.aax = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairOnAxesEnabled = function (a, b) {
        a.aag = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairUseInterpolation = function (a, b) {
        a.aai = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairThickness = function (a, b) {
        a.jq = b;
    };
    AnnotationLayerProxy.prototype.isCrosshairLayer = function (a) {
        return typeCast(CrosshairLayer.$, a) !== null;
    };
    AnnotationLayerProxy.prototype.setFinalValuePrecision = function (a, b) {
        a.aan = b;
    };
    AnnotationLayerProxy.prototype.setFinalValueBackground = function (a, b) {
        a.abh = b;
    };
    AnnotationLayerProxy.prototype.setFinalValueForeground = function (a, b) {
        a.abj = b;
    };
    AnnotationLayerProxy.prototype.setContentMemberPath = function (a, b) {
        a.adb = b;
    };
    AnnotationLayerProxy.prototype.setCalloutsAllowedPositions = function (a, b) {
        a.aan = b;
    };
    AnnotationLayerProxy.prototype.setLabelMemberPath = function (a, b) {
        a.adp = b;
    };
    AnnotationLayerProxy.prototype.setXMemberPath = function (a, b) {
        a.ad5 = b;
    };
    AnnotationLayerProxy.prototype.setYMemberPath = function (a, b) {
        a.ad8 = b;
    };
    AnnotationLayerProxy.prototype.setTargetSeries = function (a, b) {
        if (typeCast(CalloutLayer.$, a) !== null) {
            a.aas = b;
        }
        else {
            a.aal = b;
        }
    };
    AnnotationLayerProxy.prototype.setCollisionChannel = function (a, b) {
        a.ac8 = b;
    };
    AnnotationLayerProxy.prototype.setIsAutoCalloutBehaviorEnabled = function (a, b) {
        a.abj = b;
    };
    AnnotationLayerProxy.prototype.setGreedyCollisionMode = function (a, b) {
        a.aai = b ? 2 : 0;
    };
    AnnotationLayerProxy.prototype.setCollisionMode = function (a, b) {
        a.aai = b;
    };
    AnnotationLayerProxy.prototype.setUseItemColorForFill = function (a, b) {
        a.abq = b;
    };
    AnnotationLayerProxy.prototype.setUseItemColorForOutline = function (a, b) {
        a.abr = b;
    };
    AnnotationLayerProxy.prototype.setCalloutStrokeThickness = function (a, b) {
        a.acd = b;
    };
    AnnotationLayerProxy.prototype.setUseAutoContrastingLabelColors = function (a, b) {
        a.abo = b;
    };
    AnnotationLayerProxy.prototype.setCalloutBackground = function (a, b) {
        a.af1 = b;
    };
    AnnotationLayerProxy.prototype.setCalloutTextStyle = function (a, b) {
        if (b == null) {
            return;
        }
        var c = a;
        c.adv = b.fontString;
    };
    AnnotationLayerProxy.prototype.setAutoCalloutLabelPrecision = function (a, b) {
        a.acg = b;
    };
    AnnotationLayerProxy.prototype.setCalloutLightColor = function (a, b) {
        a.af4 = b;
    };
    AnnotationLayerProxy.prototype.setCalloutDarkColor = function (a, b) {
        a.af2 = b;
    };
    AnnotationLayerProxy.prototype.setCalloutOutline = function (a, b) {
        a.af5 = b;
    };
    AnnotationLayerProxy.prototype.setCalloutLeaderBrush = function (a, b) {
        a.af3 = b;
    };
    AnnotationLayerProxy.prototype.setCalloutTextColor = function (a, b) {
        a.af6 = b;
    };
    AnnotationLayerProxy.prototype.setShouldTruncateOnBoundaryCollisions = function (a, b) {
        a.abn = b;
    };
    AnnotationLayerProxy.prototype.setUseDedicatedLanes = function (a, b) {
        a.aag = b ? 2 : 0;
    };
    AnnotationLayerProxy.prototype.isCalloutLayer = function (a) {
        if (typeCast(CalloutLayer.$, a) !== null) {
            return true;
        }
        return false;
    };
    AnnotationLayerProxy.prototype.isDataToolTipLayer = function (a) {
        if (typeCast(DataToolTipLayer.$, a) !== null) {
            return true;
        }
        return false;
    };
    AnnotationLayerProxy.prototype.isFinalValueLayer = function (a) {
        if (typeCast(FinalValueLayer.$, a) !== null) {
            return true;
        }
        return false;
    };
    AnnotationLayerProxy.prototype.addCalloutStyleUpdating = function (a, b) {
        var c = a;
        c.calloutStyleUpdating = delegateCombine(c.calloutStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.removeCalloutStyleUpdating = function (a, b) {
        var c = a;
        c.calloutStyleUpdating = delegateRemove(c.calloutStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.addCalloutRenderStyleUpdating = function (a, b) {
        var c = a;
        c.calloutRenderStyleUpdating = delegateCombine(c.calloutRenderStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.removeCalloutRenderStyleUpdating = function (a, b) {
        var c = a;
        c.calloutRenderStyleUpdating = delegateRemove(c.calloutRenderStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.setCalloutStyleUpdatingEventEnabled = function (a, b) {
        a.abm = b;
    };
    AnnotationLayerProxy.prototype.setUseValueForAutoCalloutLabels = function (a, b) {
        a.abt = b;
    };
    AnnotationLayerProxy.prototype.setCalloutRenderStyleUpdatingEventEnabled = function (a, b) {
        a.abl = b;
    };
    AnnotationLayerProxy.prototype.updateDataToolTipPropertyByName = function (a, b, c) {
        a.afx(b, c);
    };
    AnnotationLayerProxy.prototype.getIsAutoCalloutBehaviorEnabled = function (a) {
        return a.abj;
    };
    AnnotationLayerProxy.prototype.setValueMode = function (a, b) {
        a.aan = b;
    };
    AnnotationLayerProxy.prototype.setUseLegend = function (a, b) {
        a.xq = b;
    };
    AnnotationLayerProxy.prototype.setTitle = function (a, b) {
        a.title = b;
    };
    AnnotationLayerProxy.prototype.setLegendItemBadgeShape = function (a, b) {
        a.legendItemBadgeShape = b;
    };
    AnnotationLayerProxy.prototype.setValueAxisAnnotationEnabled = function (a, b) {
        a.aar = b;
    };
    AnnotationLayerProxy.prototype.getValueMode = function (a) {
        return a.aan;
    };
    AnnotationLayerProxy.prototype.isValueLayer = function (a) {
        return typeCast(ValueLayer.$, a) !== null;
    };
    AnnotationLayerProxy.prototype.setBrush = function (a, b) {
        a.vk = b;
    };
    AnnotationLayerProxy.prototype.setDashArray = function (a, b) {
        var c = new DoubleCollection();
        for (var d = 0; d < b.length; d++) {
            c.add(b[d]);
        }
        a.v7 = c;
    };
    AnnotationLayerProxy.prototype.isTrendLineLayer = function (a) {
        return typeCast(TrendLineLayer.$, a) !== null;
    };
    AnnotationLayerProxy.prototype.setTrendLineTarget = function (a, b) {
        a.aab = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineType = function (a, b) {
        a.aad = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineBrush = function (a, b) {
        a.vk = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineDashArray = function (a, b) {
        a.v7 = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineDashCap = function (a, b) {
        a.v8 = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineThickness = function (a, b) {
        a.jq = b;
    };
    AnnotationLayerProxy.prototype.getTrendLineType = function (a) {
        return a.aad;
    };
    AnnotationLayerProxy.prototype.setAppearanceMode = function (a, b) {
        switch (b) {
            case "BrightnessShift":
                a.w6 = 1;
                break;
            case "SaturationShift":
                a.w6 = 2;
                break;
            case "OpacityShift":
                a.w6 = 4;
                break;
            case "DashPattern":
                a.w6 = 3;
                break;
            case "Auto":
                a.w6 = 0;
                break;
        }
    };
    AnnotationLayerProxy.$t = markType(AnnotationLayerProxy, 'AnnotationLayerProxy', Base.$, [IAnnotationLayerProxy_$type]);
    return AnnotationLayerProxy;
}(Base));
export { AnnotationLayerProxy };

==> igniteui-react-charts-19.0.1.tgz: package/esm5/lib/AnnotationLayerProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, typeCast, delegateCombine, delegateRemove, markType } from "igniteui-react-core";
import { IAnnotationLayerProxy_$type } from "./IAnnotationLayerProxy";
import { CrosshairLayer } from "./CrosshairLayer";
import { ValueLayer } from "./ValueLayer";
import { CalloutLayer } from "./CalloutLayer";
import { FinalValueLayer } from "./FinalValueLayer";
import { TrendLineLayer } from "./TrendLineLayer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { DoubleCollection } from "igniteui-react-core";
/**
 * @hidden
 */
var AnnotationLayerProxy = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AnnotationLayerProxy, _super);
    function AnnotationLayerProxy() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._container = null;
        return _this;
    }
    Object.defineProperty(AnnotationLayerProxy.prototype, "container", {
        get: function () {
            return this._container;
        },
        set: function (a) {
            this._container = a;
        },
        enumerable: false,
        configurable: true
    });
    AnnotationLayerProxy.prototype.matchesType = function (a) {
        if (!a.eu) {
            return false;
        }
        return true;
    };
    AnnotationLayerProxy.prototype.createCrosshairLayer = function () {
        var a = new CrosshairLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createValueLayer = function () {
        var a = new ValueLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createCalloutLayer = function () {
        var a = new CalloutLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createFinalValueLayer = function () {
        var a = new FinalValueLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.createTrendLineLayer = function () {
        var a = new TrendLineLayer();
        var b = this.container.getExternal(a, null, null);
        return a;
    };
    AnnotationLayerProxy.prototype.setCrosshairHorizontalLineVisibility = function (a, b) {
        a.ac7 = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairVerticalLineVisibility = function (a, b) {
        a.ac8 = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairHorizontalLineStroke = function (a, b) {
        a.acv = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairVerticalLineStroke = function (a, b) {
        a.acw = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairXAxisForeground = function (a, b) {
        a.acz = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairYAxisForeground = function (a, b) {
        a.ac2 = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairXAxisBackground = function (a, b) {
        a.acx = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairYAxisBackground = function (a, b) {
        a.ac0 = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairYAxisPrecision = function (a, b) {
        a.aa0 = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairXAxisPrecision = function (a, b) {
        a.aaz = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairOnAxesEnabled = function (a, b) {
        a.aag = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairSkipZeroValueFragments = function (a, b) {
        a.aai = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairSkipInvalidData = function (a, b) {
        a.aah = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairUseInterpolation = function (a, b) {
        a.aak = b;
    };
    AnnotationLayerProxy.prototype.setCrosshairThickness = function (a, b) {
        a.jq = b;
    };
    AnnotationLayerProxy.prototype.isCrosshairLayer = function (a) {
        return typeCast(CrosshairLayer.$, a) !== null;
    };
    AnnotationLayerProxy.prototype.setFinalValuePrecision = function (a, b) {
        a.aan = b;
    };
    AnnotationLayerProxy.prototype.setFinalValueBackground = function (a, b) {
        a.abh = b;
    };
    AnnotationLayerProxy.prototype.setFinalValueForeground = function (a, b) {
        a.abj = b;
    };
    AnnotationLayerProxy.prototype.setContentMemberPath = function (a, b) {
        a.adq = b;
    };
    AnnotationLayerProxy.prototype.setCalloutsAllowedPositions = function (a, b) {
        a.aan = b;
    };
    AnnotationLayerProxy.prototype.setLabelMemberPath = function (a, b) {
        a.ad4 = b;
    };
    AnnotationLayerProxy.prototype.setXMemberPath = function (a, b) {
        a.aek = b;
    };
    AnnotationLayerProxy.prototype.setYMemberPath = function (a, b) {
        a.aen = b;
    };
    AnnotationLayerProxy.prototype.setTargetSeries = function (a, b) {
        if (typeCast(CalloutLayer.$, a) !== null) {
            a.aas = b;
        }
        else {
            a.aal = b;
        }
    };
    AnnotationLayerProxy.prototype.setCollisionChannel = function (a, b) {
        a.adn = b;
    };
    AnnotationLayerProxy.prototype.setIsAutoCalloutBehaviorEnabled = function (a, b) {
        a.abq = b;
    };
    AnnotationLayerProxy.prototype.setGreedyCollisionMode = function (a, b) {
        a.aai = b ? 2 : 0;
    };
    AnnotationLayerProxy.prototype.setCollisionMode = function (a, b) {
        a.aai = b;
    };
    AnnotationLayerProxy.prototype.setUseItemColorForFill = function (a, b) {
        a.abx = b;
    };
    AnnotationLayerProxy.prototype.setUseItemColorForOutline = function (a, b) {
        a.aby = b;
    };
    AnnotationLayerProxy.prototype.setCalloutStrokeThickness = function (a, b) {
        a.aco = b;
    };
    AnnotationLayerProxy.prototype.setUseAutoContrastingLabelColors = function (a, b) {
        a.abv = b;
    };
    AnnotationLayerProxy.prototype.setCalloutBackground = function (a, b) {
        a.agk = b;
    };
    AnnotationLayerProxy.prototype.setCalloutTextStyle = function (a, b) {
        if (b == null) {
            return;
        }
        var c = a;
        c.aea = b.fontString;
    };
    AnnotationLayerProxy.prototype.setAutoCalloutLabelPrecision = function (a, b) {
        a.acs = b;
    };
    AnnotationLayerProxy.prototype.setCalloutLightColor = function (a, b) {
        a.agn = b;
    };
    AnnotationLayerProxy.prototype.setCalloutDarkColor = function (a, b) {
        a.agl = b;
    };
    AnnotationLayerProxy.prototype.setCalloutOutline = function (a, b) {
        a.ago = b;
    };
    AnnotationLayerProxy.prototype.setCalloutLeaderBrush = function (a, b) {
        a.agm = b;
    };
    AnnotationLayerProxy.prototype.setCalloutTextColor = function (a, b) {
        a.agp = b;
    };
    AnnotationLayerProxy.prototype.setShouldTruncateOnBoundaryCollisions = function (a, b) {
        a.abu = b;
    };
    AnnotationLayerProxy.prototype.setUseDedicatedLanes = function (a, b) {
        a.aag = b ? 2 : 0;
    };
    AnnotationLayerProxy.prototype.isCalloutLayer = function (a) {
        if (typeCast(CalloutLayer.$, a) !== null) {
            return true;
        }
        return false;
    };
    AnnotationLayerProxy.prototype.isDataToolTipLayer = function (a) {
        if (typeCast(DataToolTipLayer.$, a) !== null) {
            return true;
        }
        return false;
    };
    AnnotationLayerProxy.prototype.isFinalValueLayer = function (a) {
        if (typeCast(FinalValueLayer.$, a) !== null) {
            return true;
        }
        return false;
    };
    AnnotationLayerProxy.prototype.addCalloutStyleUpdating = function (a, b) {
        var c = a;
        c.calloutStyleUpdating = delegateCombine(c.calloutStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.removeCalloutStyleUpdating = function (a, b) {
        var c = a;
        c.calloutStyleUpdating = delegateRemove(c.calloutStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.addCalloutRenderStyleUpdating = function (a, b) {
        var c = a;
        c.calloutRenderStyleUpdating = delegateCombine(c.calloutRenderStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.removeCalloutRenderStyleUpdating = function (a, b) {
        var c = a;
        c.calloutRenderStyleUpdating = delegateRemove(c.calloutRenderStyleUpdating, b);
    };
    AnnotationLayerProxy.prototype.setCalloutStyleUpdatingEventEnabled = function (a, b) {
        a.abt = b;
    };
    AnnotationLayerProxy.prototype.setUseValueForAutoCalloutLabels = function (a, b) {
        a.ab0 = b;
    };
    AnnotationLayerProxy.prototype.setCalloutRenderStyleUpdatingEventEnabled = function (a, b) {
        a.abs = b;
    };
    AnnotationLayerProxy.prototype.updateDataToolTipPropertyByName = function (a, b, c) {
        a.afx(b, c);
    };
    AnnotationLayerProxy.prototype.getIsAutoCalloutBehaviorEnabled = function (a) {
        return a.abq;
    };
    AnnotationLayerProxy.prototype.setValueMode = function (a, b) {
        a.aan = b;
    };
    AnnotationLayerProxy.prototype.setUseLegend = function (a, b) {
        a.xq = b;
    };
    AnnotationLayerProxy.prototype.setTitle = function (a, b) {
        a.title = b;
    };
    AnnotationLayerProxy.prototype.setLegendItemBadgeShape = function (a, b) {
        a.legendItemBadgeShape = b;
    };
    AnnotationLayerProxy.prototype.setValueAxisAnnotationEnabled = function (a, b) {
        a.aar = b;
    };
    AnnotationLayerProxy.prototype.getValueMode = function (a) {
        return a.aan;
    };
    AnnotationLayerProxy.prototype.isValueLayer = function (a) {
        return typeCast(ValueLayer.$, a) !== null;
    };
    AnnotationLayerProxy.prototype.setBrush = function (a, b) {
        a.vk = b;
    };
    AnnotationLayerProxy.prototype.setDashArray = function (a, b) {
        var c = new DoubleCollection();
        for (var d = 0; d < b.length; d++) {
            c.add(b[d]);
        }
        a.v7 = c;
    };
    AnnotationLayerProxy.prototype.isTrendLineLayer = function (a) {
        return typeCast(TrendLineLayer.$, a) !== null;
    };
    AnnotationLayerProxy.prototype.setTrendLineTarget = function (a, b) {
        a.aab = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineType = function (a, b) {
        a.aad = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineBrush = function (a, b) {
        a.vk = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineDashArray = function (a, b) {
        a.v7 = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineDashCap = function (a, b) {
        a.v8 = b;
    };
    AnnotationLayerProxy.prototype.setTrendLineThickness = function (a, b) {
        a.jq = b;
    };
    AnnotationLayerProxy.prototype.getTrendLineType = function (a) {
        return a.aad;
    };
    AnnotationLayerProxy.prototype.setAppearanceMode = function (a, b) {
        switch (b) {
            case "BrightnessShift":
                a.w6 = 1;
                break;
            case "SaturationShift":
                a.w6 = 2;
                break;
            case "OpacityShift":
                a.w6 = 4;
                break;
            case "DashPattern":
                a.w6 = 3;
                break;
            case "Auto":
                a.w6 = 0;
                break;
        }
    };
    AnnotationLayerProxy.$t = markType(AnnotationLayerProxy, 'AnnotationLayerProxy', Base.$, [IAnnotationLayerProxy_$type]);
    return AnnotationLayerProxy;
}(Base));
export { AnnotationLayerProxy };
